]> granicus.if.org Git - mutt/commitdiff
Fix sidebar references to the "new count" to be "unread". (closes #3908)
authorKevin McCarthy <kevin@8t8.us>
Thu, 19 Jan 2017 22:58:13 +0000 (14:58 -0800)
committerKevin McCarthy <kevin@8t8.us>
Thu, 19 Jan 2017 22:58:13 +0000 (14:58 -0800)
%N in $sidebar_format and "new"in $sidebar_sort_method actually use
the unread message count.  Update the documentation to mention that.

Add an "unread" method to $sidebar_sort_method, but preserve "new" for
compatibility.

Change the SORT_COUNT_NEW constant to SORT_UNREAD, so the code is also
consistent with the meaning.

Thanks to cri for reporting the problem and suggesting where to fix it
in the code.

doc/manual.xml.head
init.h
sidebar.c
sort.h

index 4a475159850b1991684458ee9a11e58a396d2337..4a99f3de1af73281658f3dbf32e64118432e19f5 100644 (file)
@@ -8465,12 +8465,16 @@ please have a look at the mixmaster documentation.
          </row>
          <row>
            <entry><literal>new</literal></entry>
-           <entry>Number of new messages</entry>
+           <entry>Number of unread messages</entry>
          </row>
          <row>
            <entry><literal>path</literal></entry>
            <entry>Alphabetically by path</entry>
          </row>
+         <row>
+           <entry><literal>unread</literal></entry>
+           <entry>Number of unread messages</entry>
+         </row>
          <row>
            <entry><literal>unsorted</literal></entry>
            <entry>Do not resort the paths</entry>
--- a/sidebar.c
+++ b/sidebar.c
@@ -260,7 +260,7 @@ static int cb_qsort_sbe (const void *a, const void *b)
     case SORT_COUNT:
       result = (b2->msg_count - b1->msg_count);
       break;
-    case SORT_COUNT_NEW:
+    case SORT_UNREAD:
       result = (b2->msg_unread - b1->msg_unread);
       break;
     case SORT_FLAGGED:
@@ -363,7 +363,7 @@ static void sort_entries (void)
 
   /* These are the only sort methods we understand */
   if ((ssm == SORT_COUNT)     ||
-      (ssm == SORT_COUNT_NEW) ||
+      (ssm == SORT_UNREAD)    ||
       (ssm == SORT_FLAGGED)   ||
       (ssm == SORT_PATH))
     qsort (Entries, EntryCount, sizeof (*Entries), cb_qsort_sbe);
diff --git a/sort.h b/sort.h
index 0706261ec94c1becd2e19e5f4b3bcc67607bb5a4..9b87af9657af6b166a678298ada8b8fb0f90259f 100644 (file)
--- a/sort.h
+++ b/sort.h
@@ -32,7 +32,7 @@
 #define SORT_TRUST     13
 #define SORT_SPAM      14
 #define SORT_COUNT     15
-#define SORT_COUNT_NEW 16
+#define SORT_UNREAD    16
 #define SORT_FLAGGED   17
 #define SORT_PATH      18
diff --git a/init.h b/init.h
index 6d23e2d5747e08018c055411ead073ae1caad9ff..6734ded4325fc1b79e98a6c45b257e52270978b8 100644 (file)
--- a/init.h
+++ b/init.h
@@ -2757,7 +2757,7 @@ struct option_t MuttVars[] = {
   ** .dl
   ** .dt %B  .dd Name of the mailbox
   ** .dt %S  .dd * Size of mailbox (total number of messages)
** .dt %N  .dd * Number of New messages in the mailbox
   ** .dt %n  .dd N if mailbox has new mail, blank otherwise
   ** .dt %F  .dd * Number of Flagged messages in the mailbox
   ** .dt %!  .dd ``!'' : one flagged message;
@@ -2828,7 +2828,10 @@ struct option_t MuttVars[] = {
   ** .dd alpha (alphabetically)
   ** .dd count (all message count)
   ** .dd flagged (flagged message count)
-  ** .dd new (new message count)
+  ** .dd name (alphabetically)
+  ** .dd new (unread message count)
+  ** .dd path (alphabetically)
+  ** .dd unread (unread message count)
   ** .dd unsorted
   ** .ie
   ** .pp
@@ -3862,8 +3865,9 @@ const struct mapping_t SortSidebarMethods[] = {
   { "flagged",         SORT_FLAGGED },
   { "mailbox-order",   SORT_ORDER },
   { "name",            SORT_PATH },
-  { "new",             SORT_COUNT_NEW },
+  { "new",             SORT_UNREAD },  /* kept for compatibility */
   { "path",            SORT_PATH },
+  { "unread",          SORT_UNREAD },
   { "unsorted",                SORT_ORDER },
   { NULL,              0 }
 };
@@ -2757,7 +2757,7 @@ struct option_t MuttVars[] = {
   ** .dt %B  .dd Name of the mailbox
   ** .dt %S  .dd * Size of mailbox (total number of messages)
-  ** .dt %N  .dd * Number of New messages in the mailbox
+  ** .dt %N  .dd * Number of unread messages in the mailbox
   ** .dt %n  .dd N if mailbox has new mail, blank otherwise
   ** .dt %F  .dd * Number of Flagged messages in the mailbox
index 2afbbb32eeadf79510cecb0ad63ecbb4426b00b2..a7abbe7181dcb0c541e419be4ea9073ebeaa1a49 100644 (file)